Welcome to Bayes Window's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   example_notebooks/lfp_example/quick_lfp
   example_notebooks/lfp_example/lfp_roc
   example_notebooks/neurons_example/quickstart
   example_notebooks/neurons_example/posteriors
   example_notebooks/neurons_example/detailed_workflow
   
   example_notebooks/motivation/multilevel_modeling_lfp
   example_notebooks/motivation/multilevel_modeling_neurons
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
